/**
 * Defines events that the layout system emits
 *
 * 'firstLoaded' - emitted when the layout has finished loading the first time
 * using the declarative API after {@link DEFAULT_RELOAD_BUFFER} ms.
 * <br/>
 * 'itemAdded' - emitted when an item is added to the layout'
 * <br/>
 * 'itemRemoved' - emitted when an item is removed from the layout'
 * <br/>
 * 'itemResized' - emitted when the user drags the divider to resize elements
 * @public
 */
export declare const LayoutEmitEvents: {
    readonly firstLoaded: "first-loaded";
    readonly itemAdded: "item-added";
    readonly itemRemoved: "item-removed";
    readonly itemResized: "item-resized";
};
/**
 * Defines events that the layout system listens for
 *
 * 'changeTitle' - emit this from a contained item to update the title of the window that contains it.
 * 'autosave' - emit this from a contained item to hint to the layout system that it should autosave the layout. A contained item should do this if it has just changed some state it would like to persist. See {@link LayoutComponentWithState}.
 * @public
 */
export declare const LayoutReceiveEvents: {
    readonly changeTitle: "change-title";
    readonly autosave: "autosave";
};
/**
 * Defines the shape of the detail that the layout listens works with for events it listens on
 *
 * 'changeTitle' - `title` is the string you want to set. For `mode`: `replace` will set the title to be `title`, `suffix` will append `title` to the end of the existing title.
 * 'autosave' - no other parameters.
 * @public
 */
export type LayoutReceiveEventsDetail = {
    changeTitle: {
        title: string;
        mode: 'replace' | 'suffix';
    };
    autosave: void;
};
//# sourceMappingURL=events.d.ts.map