/**
 * Defines events that the layout system emits
 *
 * 'firstLoaded' - emitted when the layout has finished loading the first time
 * using the declarative API after {@link DEFAULT_RELOAD_BUFFER} ms.
 * <br/>
 * 'itemAdded' - emitted when an item is added to the layout'
 * <br/>
 * 'itemRemoved' - emitted when an item is removed from the layout'
 * <br/>
 * 'itemResized' - emitted when the user drags the divider to resize elements
 * @public
 */
export const LayoutEmitEvents = {
    firstLoaded: 'first-loaded',
    itemAdded: 'item-added',
    itemRemoved: 'item-removed',
    itemResized: 'item-resized',
};
/**
 * Defines events that the layout system listens for
 *
 * 'changeTitle' - emit this from a contained item to update the title of the window that contains it.
 * 'autosave' - emit this from a contained item to hint to the layout system that it should autosave the layout. A contained item should do this if it has just changed some state it would like to persist. See {@link LayoutComponentWithState}.
 * @public
 */
export const LayoutReceiveEvents = {
    changeTitle: 'change-title',
    autosave: 'autosave',
};
